# Overview

**sardinecake** is a Python library with accompanying scripts
to manage libvirt VMs via an OCI registry.

![sardine cake](sardinecake.png)


Check out the [usage](usage.md) section for further information, including how to [install](usage.md#installation) the project.


`sardinecake` is heavily influenced by the fantastic [`tart`](https://tart.run) toolset,
that manages macOS (and Linux) VMs on Apple Silicon.
I needed something similar to run Windows VMs on my Linux machines, hence i wrote `sardinecake`.

!!! note

    This project is under active development.

## Links

- Development: [https://git.iem.at/devtools/sardinecake](https://git.iem.at/devtools/sardinecake)
- PyPi: [https://pypi.org/project/sardinecake/](https://pypi.org/project/sardinecake/)
- Documentation: [https://sardinecake.readthedocs.io/](https://sardinecake.readthedocs.io/)
- Bug/Issue Tracker: [https://git.iem.at/devtools/sardinecake/-/issues](https://git.iem.at/devtools/sardinecake/-/issues)
